@@ -12,6 +12,8 @@ Parser::Parser(Rules &rules, States &states)
 {
     d_options.setParserInfo(d_matched, d_rawStringContents);
     s_ignoreToken = d_token__;      // set by ParserBase to _UNDETERMINED
-    setDebug(d_options.debug());
+//    setDebug(d_options.debug());    // write debug code to the generated
+                                    // lex.cc file 
+    setDebug(d_options.ownParserDebug());
 }
 
